# [RTUweatherBot](https://t.me/RTUweatherBot)

**RTUweatherBot** - это Telegram-бот, предназначенный для получение информации о погодных условиях. В функциональность входит предоставление прогноза погоды в конкретном городе на различные промежутки времени, гибкая система настройки уведомлений, рекомендации по подбору гардероба и прочее.

## Getting Started

Инструкция о том, как получить копию этого ПО и запустить его на локальном компьютере с целью разработки и тестирования. Подробную информацию о развертывании ПО в условиях эксплуатации см. в разделе «Развертывание».

### Prerequisites

Что нужно для установки ПО, инструкции по установке дополнительных компонентов.

- [Python 3.9.8+](https://www.python.org/downloads/)

### Installing

	under development

### Settings

Настройка производится через переменные окружения. 
Для запуска в docker-compose переменные окружения необходимо объявить в файле ``./.env``.

Доступные переменные окружения:

| Наименование      | Описание                            |
|-------------------|-------------------------------------|
| RTU_WEATHER_BOT_TOKEN | Токен для авторизации telegram-бота |

## Authors

- [curlypelican](https://github.com/curlypelican)
- [devilishgrapefruit](https://github.com/devilishgrapefruit)
- [Alexinet](https://github.com/Alexinet)
